// Title: Camera focal length animation
// Author: Michael Horvath, http://isometricland.net
// Created: 2015-11-19
// Updated: 2015-11-19
// This file is licensed under the terms of the GFDL.
// +kfi0 +kff15
// +K0.5

#version 3.7
#include "axes_macro.inc"	// available from the POV-Ray Object Collection
#include "screen.inc"		// requires the updated version available here: http://news.povray.org/povray.binaries.scene-files/thread/%3C4afccd8a%241%40news.povray.org%3E/
#include "math.inc"
#include "Transforms.inc"

global_settings
{
	assumed_gamma	1.0
	adc_bailout		0.005
	max_trace_level	50
	charset			utf8
	ambient_light	0
	radiosity
	{
		pretrace_start	0.08
		pretrace_end	0.01
		count			50
		error_bound		0.1
		recursion_limit	1
		normal			on
		brightness		0.8
		always_sample	yes
		gray_threshold	0.8
		media			on
	}
}

background {color srgb <096,144,255,>/255}

#declare Jitter				= 0.001;
#declare CircumsphereRadius	= sqrt(3);						// distance from the center to a corner of the cube (radius of the sphere circumscribing the cube)
#declare StartDistance		= CircumsphereRadius/2;
#declare StartAngle			= atan2d(StartDistance, 1);		// begin the animation with the proper angle starting at the corner of the cube (otherwise, the camera will lie inside the object)
#declare AngleOfView		= StartAngle + clock * (90 - StartAngle) - Jitter;	// do a linear interpolation between the start angle and the final angle (a tiny bit less than 90 degrees)
#declare CameraDistance		= tand(AngleOfView);			// calculate the distance based on the angle (the distance corresponds to the exsecant of the angle)
#declare CameraLocation		= -z * CameraDistance;
#declare CameraDirection	= +z * CameraDistance;
#declare CameraRight		= +x * 5/2;
#declare CameraUp			= +y * 5/2;
#declare CameraTransform	= transform
{
	rotate	<atand(sind(45)),45,0>
//	scale	2/3
//	translate y/2
}
#declare CameraLocation		= vtransform(CameraLocation, CameraTransform);
#declare CameraDirection	= vtransform(CameraDirection, CameraTransform);
#declare CameraRight		= vtransform(CameraRight, CameraTransform);
#declare CameraUp			= vtransform(CameraUp, CameraTransform);
//#declare CameraAngle		= (90 - AngleOfView) * 2;
//#declare CameraAngle		= StartAngle;
#declare CameraAngle		= degrees(2 * atan(vlength(CameraRight)/vlength(CameraDirection)/2));
#declare CameraText_1		= text
{
	ttf "verdana.ttf" concat("", str(CameraAngle,0,1), "") 0.01, <0,0>
	scale 0.05
}
#declare CameraText_2		= text
{
	ttf "verdana.ttf" concat("", str(vlength(CameraLocation)*10,0,1), "m") 0.01, <0,0>
	scale 0.05
}

Set_Camera_Alt(CameraLocation, CameraDirection, CameraRight, CameraUp, 0)
Screen_Object(CameraText_1, <1,0>, <0.04,0.07>, true, 0.01)
Screen_Object(CameraText_2, <1,0>, <0.04,0.02>, true, 0.01)

camera
{
	location		CameraLocation
	direction		CameraDirection
	up				CameraUp
	right			CameraRight
//	aperture		0.00001
//	blur_samples	100
//	focal_point		0
}

light_source
{
	<-30,+30,-30,>
	color rgb	1
	rotate		y * 330
	parallel
	shadowless
}

light_source
{
	<-30,+30,-30,>
	color rgb	1
	rotate		y * 090
	parallel
//	shadowless
}

// the coordinate grid and axes
Axes_Macro
(
	10,		// Axes_axesSize,	The distance from the origin to one of the grid's edges.	(float)
	0.1,	// Axes_majUnit,	The size of each large-unit square.	(float)
	10,		// Axes_minUnit,	The number of small-unit squares that make up a large-unit square.	(integer)
	0.0005,	// Axes_thickRatio,	The thickness of the grid lines (as a factor of axesSize).	(float)
	off,		// Axes_aBool,		Turns the axes on/off. (boolian)
	off,	// Axes_mBool,		Turns the minor units on/off. (boolian)
	off,	// Axes_xBool,		Turns the plane perpendicular to the x-axis on/off.	(boolian)
	on,		// Axes_yBool,		Turns the plane perpendicular to the y-axis on/off.	(boolian)
	off		// Axes_zBool,		Turns the plane perpendicular to the z-axis on/off.	(boolian)
)

object
{
	Axes_Object
//	translate -0.0001
//	no_shadow
}

merge
{
	// main structure
	intersection
	{
		plane {+x + y,0 translate +y * 3/4}
		plane {-x + y,0 translate +y * 3/4}
		box {-1,+1}
		translate	+y
		scale		1/2
	}
	// chimney
	box {<0,0,0,>,<+1/8,+1/1,+1/8,>}
	// doorway and floor clip
	clipped_by
	{
		merge
		{
			box {<-1/8,+0/1,-1,>,<+1/8,+1/4,+1/1,> inverse}
			plane {+y,-0.1}
		}
	}
	hollow
	pigment {color srgbt <1/1,1/1,1/1,1/2,>}
}
